numpy.ndarray
=============

.. currentmodule:: numpy

.. autoclass:: ndarray

   

   .. HACK
      .. autosummary::
         :toctree:
      
         ndarray.__init__
         ndarray.all
         ndarray.any
         ndarray.argmax
         ndarray.argmin
         ndarray.argsort
         ndarray.astype
         ndarray.byteswap
         ndarray.choose
         ndarray.clip
         ndarray.compress
         ndarray.conj
         ndarray.conjugate
         ndarray.copy
         ndarray.cumprod
         ndarray.cumsum
         ndarray.diagonal
         ndarray.dot
         ndarray.dump
         ndarray.dumps
         ndarray.fill
         ndarray.flatten
         ndarray.getfield
         ndarray.item
         ndarray.itemset
         ndarray.max
         ndarray.mean
         ndarray.min
         ndarray.newbyteorder
         ndarray.nonzero
         ndarray.prod
         ndarray.ptp
         ndarray.put
         ndarray.ravel
         ndarray.repeat
         ndarray.reshape
         ndarray.resize
         ndarray.round
         ndarray.searchsorted
         ndarray.setasflat
         ndarray.setfield
         ndarray.setflags
         ndarray.sort
         ndarray.squeeze
         ndarray.std
         ndarray.sum
         ndarray.swapaxes
         ndarray.take
         ndarray.tofile
         ndarray.tolist
         ndarray.tostring
         ndarray.trace
         ndarray.transpose
         ndarray.var
         ndarray.view



   

   .. HACK
      .. autosummary::
         :toctree:
      
         ndarray.T
         ndarray.base
         ndarray.ctypes
         ndarray.data
         ndarray.dtype
         ndarray.flags
         ndarray.flat
         ndarray.imag
         ndarray.itemsize
         ndarray.nbytes
         ndarray.ndim
         ndarray.real
         ndarray.shape
         ndarray.size
         ndarray.strides

